@@ -6,6 +6,6 @@ from . import accessors
 
 __author__ = """Philipp Temminghoff"""
 __email__ = 'phil65@kodi.tv'
-__version__ = '0.8.8'
+__version__ = '0.0.3'
 
-__all__ = ["accessors"]
+__all__ = ["accessors", "utils"]
