@@ -3,11 +3,11 @@
 @author: Philipp Temminghoff
 """
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 
 
-@pd.api.extensions.register_series_accessor("helpers")
+@pd.api.extensions.register_series_accessor("pt")
 class SeriesAccessor(object):
     def __init__(self, pandas_obj):
         self._obj = pandas_obj
